# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import pulumi
from enum import Enum

__all__ = [
    'AuthPolicyDecision',
    'AuthPolicyPermissionLevel',
    'AuthPolicyTokenType',
    'CloudProvider',
    'EnvironmentPermission',
    'PulumiOperation',
    'RbacPermission',
    'ScanSchedule',
    'TargetActionType',
    'TeamStackPermissionScope',
    'WebhookFilters',
    'WebhookFormat',
    'WebhookGroup',
]


@pulumi.type_token("pulumiservice:index:AuthPolicyDecision")
class AuthPolicyDecision(_builtins.str, Enum):
    DENY = "deny"
    """
    A deny rule for Oidc Issuer Policy.
    """
    ALLOW = "allow"
    """
    An allow rule for Oidc Issuer Policy.
    """


@pulumi.type_token("pulumiservice:index:AuthPolicyPermissionLevel")
class AuthPolicyPermissionLevel(_builtins.str, Enum):
    STANDARD = "standard"
    """
    Standard level of permissions.
    """
    ADMIN = "admin"
    """
    Admin level of permissions.
    """


@pulumi.type_token("pulumiservice:index:AuthPolicyTokenType")
class AuthPolicyTokenType(_builtins.str, Enum):
    PERSONAL = "personal"
    """
    Personal Pulumi token. Requires userLogin field to be filled.
    """
    TEAM = "team"
    """
    Team Pulumi token. Requires teamName field to be filled.
    """
    ORGANIZATION = "organization"
    """
    Organization Pulumi token. Requires authorizedPermissions field to be filled.
    """
    RUNNER = "runner"
    """
    Deployment Runner Pulumi token. Requires runnerID field to be filled.
    """


@pulumi.type_token("pulumiservice:index:CloudProvider")
class CloudProvider(_builtins.str, Enum):
    AWS = "aws"
    """
    Amazon Web Services
    """
    AZURE_NATIVE = "azure-native"
    """
    Microsoft Azure
    """
    GCP = "gcp"
    """
    Google Cloud Platform
    """
    KUBERNETES = "kubernetes"
    """
    Kubernetes
    """
    OCI = "oci"
    """
    Oracle Cloud Infrastructure
    """


@pulumi.type_token("pulumiservice:index:EnvironmentPermission")
class EnvironmentPermission(_builtins.str, Enum):
    NONE = "none"
    """
    No permissions.
    """
    READ = "read"
    """
    Permission to read environment definition only.
    """
    OPEN = "open"
    """
    Permission to open and read the environment.
    """
    WRITE = "write"
    """
    Permission to open, read and update the environment.
    """
    ADMIN = "admin"
    """
    Permission for all operations on the environment.
    """


@pulumi.type_token("pulumiservice:index:PulumiOperation")
class PulumiOperation(_builtins.str, Enum):
    UPDATE = "update"
    """
    Analogous to `pulumi up` command.
    """
    PREVIEW = "preview"
    """
    Analogous to `pulumi preview` command.
    """
    REFRESH = "refresh"
    """
    Analogous to `pulumi refresh` command.
    """
    DESTROY = "destroy"
    """
    Analogous to `pulumi destroy` command.
    """


@pulumi.type_token("pulumiservice:index:RbacPermission")
class RbacPermission(_builtins.str, Enum):
    READ = "environment:read"
    """
    Read permission.
    """
    READ_DECRYPT = "environment:read_decrypt"
    """
    Read and decrypt permission.
    """
    OPEN = "environment:open"
    """
    Open permission.
    """
    WRITE = "environment:write"
    """
    Write permission.
    """
    DELETE = "environment:delete"
    """
    Delete permission.
    """
    CLONE = "environment:clone"
    """
    Clone permission.
    """
    ROTATE = "environment:rotate"
    """
    Rotate permission.
    """


@pulumi.type_token("pulumiservice:index:ScanSchedule")
class ScanSchedule(_builtins.str, Enum):
    NONE = "none"
    """
    Disable automated scanning.
    """
    DAILY = "daily"
    """
    Run automated scans once per day.
    """


@pulumi.type_token("pulumiservice:index:TargetActionType")
class TargetActionType(_builtins.str, Enum):
    UPDATE = "update"
    """
    Update action type for approval rules.
    """


@pulumi.type_token("pulumiservice:index:TeamStackPermissionScope")
class TeamStackPermissionScope(_builtins.float, Enum):
    READ = 101
    """
    Grants read permissions to stack.
    """
    EDIT = 102
    """
    Grants edit permissions to stack.
    """
    ADMIN = 103
    """
    Grants admin permissions to stack.
    """


@pulumi.type_token("pulumiservice:index:WebhookFilters")
class WebhookFilters(_builtins.str, Enum):
    STACK_CREATED = "stack_created"
    """
    Trigger a webhook when a stack is created. Only valid for org webhooks.
    """
    STACK_DELETED = "stack_deleted"
    """
    Trigger a webhook when a stack is deleted. Only valid for org webhooks.
    """
    UPDATE_SUCCEEDED = "update_succeeded"
    """
    Trigger a webhook when a stack update succeeds.
    """
    UPDATE_FAILED = "update_failed"
    """
    Trigger a webhook when a stack update fails.
    """
    PREVIEW_SUCCEEDED = "preview_succeeded"
    """
    Trigger a webhook when a stack preview succeeds.
    """
    PREVIEW_FAILED = "preview_failed"
    """
    Trigger a webhook when a stack preview fails.
    """
    DESTROY_SUCCEEDED = "destroy_succeeded"
    """
    Trigger a webhook when a stack destroy succeeds.
    """
    DESTROY_FAILED = "destroy_failed"
    """
    Trigger a webhook when a stack destroy fails.
    """
    REFRESH_SUCCEEDED = "refresh_succeeded"
    """
    Trigger a webhook when a stack refresh succeeds.
    """
    REFRESH_FAILED = "refresh_failed"
    """
    Trigger a webhook when a stack refresh fails.
    """
    DEPLOYMENT_QUEUED = "deployment_queued"
    """
    Trigger a webhook when a deployment is queued.
    """
    DEPLOYMENT_STARTED = "deployment_started"
    """
    Trigger a webhook when a deployment starts running.
    """
    DEPLOYMENT_SUCCEEDED = "deployment_succeeded"
    """
    Trigger a webhook when a deployment succeeds.
    """
    DEPLOYMENT_FAILED = "deployment_failed"
    """
    Trigger a webhook when a deployment fails.
    """
    DRIFT_DETECTED = "drift_detected"
    """
    Trigger a webhook when drift is detected.
    """
    DRIFT_DETECTION_SUCCEEDED = "drift_detection_succeeded"
    """
    Trigger a webhook when a drift detection run succeeds, regardless of whether drift is detected.
    """
    DRIFT_DETECTION_FAILED = "drift_detection_failed"
    """
    Trigger a webhook when a drift detection run fails.
    """
    DRIFT_REMEDIATION_SUCCEEDED = "drift_remediation_succeeded"
    """
    Trigger a webhook when a drift remediation run succeeds.
    """
    DRIFT_REMEDIATION_FAILED = "drift_remediation_failed"
    """
    Trigger a webhook when a drift remediation run fails.
    """
    ENVIRONMENT_CREATED = "environment_created"
    """
    Trigger a webhook when a new environment is created.
    """
    ENVIRONMENT_DELETED = "environment_deleted"
    """
    Trigger a webhook when an environment is deleted.
    """
    ENVIRONMENT_REVISION_CREATED = "environment_revision_created"
    """
    Trigger a webhook when a new revision is created on an environment.
    """
    ENVIRONMENT_REVISION_RETRACTED = "environment_revision_retracted"
    """
    Trigger a webhook when a revision is retracted on an environment.
    """
    ENVIRONMENT_REVISION_TAG_CREATED = "environment_revision_tag_created"
    """
    Trigger a webhook when a revision tag is created on an environment.
    """
    ENVIRONMENT_REVISION_TAG_DELETED = "environment_revision_tag_deleted"
    """
    Trigger a webhook when a revision tag is deleted on an environment.
    """
    ENVIRONMENT_REVISION_TAG_UPDATED = "environment_revision_tag_updated"
    """
    Trigger a webhook when a revision tag is updated on an environment.
    """
    ENVIRONMENT_TAG_CREATED = "environment_tag_created"
    """
    Trigger a webhook when an environment tag is created.
    """
    ENVIRONMENT_TAG_DELETED = "environment_tag_deleted"
    """
    Trigger a webhook when an environment tag is deleted.
    """
    ENVIRONMENT_TAG_UPDATED = "environment_tag_updated"
    """
    Trigger a webhook when an environment tag is updated.
    """
    IMPORTED_ENVIRONMENT_CHANGED = "imported_environment_changed"
    """
    Trigger a webhook when an imported environment has changed.
    """


@pulumi.type_token("pulumiservice:index:WebhookFormat")
class WebhookFormat(_builtins.str, Enum):
    RAW = "raw"
    """
    The default webhook format.
    """
    SLACK = "slack"
    """
    Messages formatted for consumption by Slack incoming webhooks.
    """
    PULUMI_DEPLOYMENTS = "pulumi_deployments"
    """
    Initiate deployments on a stack from a Pulumi Cloud webhook.
    """
    MICROSOFT_TEAMS = "ms_teams"
    """
    Messages formatted for consumption by Microsoft Teams incoming webhooks.
    """


@pulumi.type_token("pulumiservice:index:WebhookGroup")
class WebhookGroup(_builtins.str, Enum):
    STACKS = "stacks"
    """
    A group of webhooks containing all stack events.
    """
    DEPLOYMENTS = "deployments"
    """
    A group of webhooks containing all deployment events.
    """
    ENVIRONMENTS = "environments"
    """
    A group of webhooks containing all environment events.
    """



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from ._enums import *

__all__ = ['InsightsAccountArgs', 'InsightsAccount']

@pulumi.input_type
class InsightsAccountArgs:
    def __init__(__self__, *,
                 account_name: pulumi.Input[_builtins.str],
                 environment: pulumi.Input[_builtins.str],
                 organization_name: pulumi.Input[_builtins.str],
                 provider: pulumi.Input['CloudProvider'],
                 scan_schedule: Optional[pulumi.Input['ScanSchedule']] = None,
                 provider_config: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a InsightsAccount resource.
        :param pulumi.Input[_builtins.str] account_name: Name of the insights account.
        :param pulumi.Input[_builtins.str] environment: The ESC environment used for provider credentials. Format: 'project/environment' with optional '@version' suffix (e.g., 'my-project/prod-env' or 'my-project/prod-env@v1.0').
        :param pulumi.Input[_builtins.str] organization_name: The organization's name.
        :param pulumi.Input['CloudProvider'] provider: The cloud provider for scanning.
        :param pulumi.Input['ScanSchedule'] scan_schedule: Schedule for automated scanning. Use 'daily' to enable daily scans, or 'none' to disable scheduled scanning. Defaults to 'none'.
        :param pulumi.Input[Mapping[str, Any]] provider_config: Provider-specific configuration as a JSON object. For AWS, specify regions to scan: {"regions": ["us-west-1", "us-west-2"]}.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Key-value tags to associate with the insights account.
        """
        pulumi.set(__self__, "account_name", account_name)
        pulumi.set(__self__, "environment", environment)
        pulumi.set(__self__, "organization_name", organization_name)
        pulumi.set(__self__, "provider", provider)
        if scan_schedule is None:
            scan_schedule = 'none'
        pulumi.set(__self__, "scan_schedule", scan_schedule)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the insights account.
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "account_name", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Input[_builtins.str]:
        """
        The ESC environment used for provider credentials. Format: 'project/environment' with optional '@version' suffix (e.g., 'my-project/prod-env' or 'my-project/prod-env@v1.0').
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> pulumi.Input[_builtins.str]:
        """
        The organization's name.
        """
        return pulumi.get(self, "organization_name")

    @organization_name.setter
    def organization_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "organization_name", value)

    @_builtins.property
    @pulumi.getter
    def provider(self) -> pulumi.Input['CloudProvider']:
        """
        The cloud provider for scanning.
        """
        return pulumi.get(self, "provider")

    @provider.setter
    def provider(self, value: pulumi.Input['CloudProvider']):
        pulumi.set(self, "provider", value)

    @_builtins.property
    @pulumi.getter(name="scanSchedule")
    def scan_schedule(self) -> pulumi.Input['ScanSchedule']:
        """
        Schedule for automated scanning. Use 'daily' to enable daily scans, or 'none' to disable scheduled scanning. Defaults to 'none'.
        """
        return pulumi.get(self, "scan_schedule")

    @scan_schedule.setter
    def scan_schedule(self, value: pulumi.Input['ScanSchedule']):
        pulumi.set(self, "scan_schedule", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Provider-specific configuration as a JSON object. For AWS, specify regions to scan: {"regions": ["us-west-1", "us-west-2"]}.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Key-value tags to associate with the insights account.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("pulumiservice:index:InsightsAccount")
class InsightsAccount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider: Optional[pulumi.Input['CloudProvider']] = None,
                 provider_config: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 scan_schedule: Optional[pulumi.Input['ScanSchedule']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Insights Account for cloud resource scanning and analysis across AWS, Azure, and GCP.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_name: Name of the insights account.
        :param pulumi.Input[_builtins.str] environment: The ESC environment used for provider credentials. Format: 'project/environment' with optional '@version' suffix (e.g., 'my-project/prod-env' or 'my-project/prod-env@v1.0').
        :param pulumi.Input[_builtins.str] organization_name: The organization's name.
        :param pulumi.Input['CloudProvider'] provider: The cloud provider for scanning.
        :param pulumi.Input[Mapping[str, Any]] provider_config: Provider-specific configuration as a JSON object. For AWS, specify regions to scan: {"regions": ["us-west-1", "us-west-2"]}.
        :param pulumi.Input['ScanSchedule'] scan_schedule: Schedule for automated scanning. Use 'daily' to enable daily scans, or 'none' to disable scheduled scanning. Defaults to 'none'.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Key-value tags to associate with the insights account.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InsightsAccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Insights Account for cloud resource scanning and analysis across AWS, Azure, and GCP.

        :param str resource_name: The name of the resource.
        :param InsightsAccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InsightsAccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider: Optional[pulumi.Input['CloudProvider']] = None,
                 provider_config: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 scan_schedule: Optional[pulumi.Input['ScanSchedule']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InsightsAccountArgs.__new__(InsightsAccountArgs)

            if account_name is None and not opts.urn:
                raise TypeError("Missing required property 'account_name'")
            __props__.__dict__["account_name"] = account_name
            if environment is None and not opts.urn:
                raise TypeError("Missing required property 'environment'")
            __props__.__dict__["environment"] = environment
            if organization_name is None and not opts.urn:
                raise TypeError("Missing required property 'organization_name'")
            __props__.__dict__["organization_name"] = organization_name
            if provider is None and not opts.urn:
                raise TypeError("Missing required property 'provider'")
            __props__.__dict__["provider"] = provider
            __props__.__dict__["provider_config"] = provider_config
            if scan_schedule is None:
                scan_schedule = 'none'
            if scan_schedule is None and not opts.urn:
                raise TypeError("Missing required property 'scan_schedule'")
            __props__.__dict__["scan_schedule"] = scan_schedule
            __props__.__dict__["tags"] = tags
            __props__.__dict__["insights_account_id"] = None
            __props__.__dict__["scheduled_scan_enabled"] = None
        replace_on_changes = pulumi.ResourceOptions(replace_on_changes=["accountName", "organizationName", "provider"])
        opts = pulumi.ResourceOptions.merge(opts, replace_on_changes)
        super(InsightsAccount, __self__).__init__(
            'pulumiservice:index:InsightsAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'InsightsAccount':
        """
        Get an existing InsightsAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = InsightsAccountArgs.__new__(InsightsAccountArgs)

        __props__.__dict__["account_name"] = None
        __props__.__dict__["environment"] = None
        __props__.__dict__["insights_account_id"] = None
        __props__.__dict__["organization_name"] = None
        __props__.__dict__["provider"] = None
        __props__.__dict__["provider_config"] = None
        __props__.__dict__["scan_schedule"] = None
        __props__.__dict__["scheduled_scan_enabled"] = None
        __props__.__dict__["tags"] = None
        return InsightsAccount(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the insights account.
        """
        return pulumi.get(self, "account_name")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Output[_builtins.str]:
        """
        The ESC environment used for provider credentials. Format: 'project/environment' with optional '@version' suffix (e.g., 'my-project/prod-env' or 'my-project/prod-env@v1.0').
        """
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter(name="insightsAccountId")
    def insights_account_id(self) -> pulumi.Output[_builtins.str]:
        """
        The insights account identifier.
        """
        return pulumi.get(self, "insights_account_id")

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> pulumi.Output[_builtins.str]:
        """
        The organization's name.
        """
        return pulumi.get(self, "organization_name")

    @_builtins.property
    @pulumi.getter
    def provider(self) -> pulumi.Output['CloudProvider']:
        """
        The cloud provider for scanning.
        """
        return pulumi.get(self, "provider")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        """
        Provider-specific configuration as a JSON object. For AWS, specify regions to scan: {"regions": ["us-west-1", "us-west-2"]}.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="scanSchedule")
    def scan_schedule(self) -> pulumi.Output['ScanSchedule']:
        """
        Schedule for automated scanning. Use 'daily' to enable daily scans, or 'none' to disable scheduled scanning. Defaults to 'none'.
        """
        return pulumi.get(self, "scan_schedule")

    @_builtins.property
    @pulumi.getter(name="scheduledScanEnabled")
    def scheduled_scan_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether scheduled scanning is enabled.
        """
        return pulumi.get(self, "scheduled_scan_enabled")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        Key-value tags to associate with the insights account.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._enums import *

__all__ = [
    'GetInsightsAccountsResult',
    'AwaitableGetInsightsAccountsResult',
    'get_insights_accounts',
    'get_insights_accounts_output',
]

@pulumi.output_type
class GetInsightsAccountsResult:
    def __init__(__self__, accounts=None):
        if accounts and not isinstance(accounts, list):
            raise TypeError("Expected argument 'accounts' to be a list")
        pulumi.set(__self__, "accounts", accounts)

    @_builtins.property
    @pulumi.getter
    def accounts(self) -> Sequence['outputs.InsightsAccountState']:
        return pulumi.get(self, "accounts")


class AwaitableGetInsightsAccountsResult(GetInsightsAccountsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInsightsAccountsResult(
            accounts=self.accounts)


def get_insights_accounts(organization_name: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInsightsAccountsResult:
    """
    Get a list of all Insights accounts for an organization.
    """
    __args__ = dict()
    __args__['organizationName'] = organization_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('pulumiservice:index:getInsightsAccounts', __args__, opts=opts, typ=GetInsightsAccountsResult).value

    return AwaitableGetInsightsAccountsResult(
        accounts=pulumi.get(__ret__, 'accounts'))
def get_insights_accounts_output(organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInsightsAccountsResult]:
    """
    Get a list of all Insights accounts for an organization.
    """
    __args__ = dict()
    __args__['organizationName'] = organization_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('pulumiservice:index:getInsightsAccounts', __args__, opts=opts, typ=GetInsightsAccountsResult)
    return __ret__.apply(lambda __response__: GetInsightsAccountsResult(
        accounts=pulumi.get(__response__, 'accounts')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from ._enums import *

__all__ = ['WebhookArgs', 'Webhook']

@pulumi.input_type
class WebhookArgs:
    def __init__(__self__, *,
                 active: pulumi.Input[_builtins.bool],
                 display_name: pulumi.Input[_builtins.str],
                 organization_name: pulumi.Input[_builtins.str],
                 payload_url: pulumi.Input[_builtins.str],
                 environment_name: Optional[pulumi.Input[_builtins.str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input['WebhookFilters']]]] = None,
                 format: Optional[pulumi.Input['WebhookFormat']] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input['WebhookGroup']]]] = None,
                 project_name: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 stack_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Webhook resource.
        :param pulumi.Input[_builtins.bool] active: Indicates whether this webhook is enabled or not.
        :param pulumi.Input[_builtins.str] display_name: The friendly name displayed in the Pulumi Cloud.
        :param pulumi.Input[_builtins.str] organization_name: Name of the organization.
        :param pulumi.Input[_builtins.str] payload_url: URL to send request to.
        :param pulumi.Input[_builtins.str] environment_name: Name of the environment. Only specified if this is an environment webhook.
        :param pulumi.Input[Sequence[pulumi.Input['WebhookFilters']]] filters: Optional set of filters to apply to the webhook. See [webhook docs](https://www.pulumi.com/docs/intro/pulumi-service/webhooks/#filters) for more information.
        :param pulumi.Input['WebhookFormat'] format: Format of the webhook payload. Can be either `raw` or `slack`. Defaults to `raw`.
        :param pulumi.Input[Sequence[pulumi.Input['WebhookGroup']]] groups: Optional set of filter groups to apply to the webhook. See [webhook docs](https://www.pulumi.com/docs/intro/pulumi-service/webhooks/#groups) for more information.
        :param pulumi.Input[_builtins.str] project_name: Name of the project. Only specified if this is a stack or environment webhook.
        :param pulumi.Input[_builtins.str] secret: Optional. secret used as the HMAC key. See [webhook docs](https://www.pulumi.com/docs/intro/pulumi-service/webhooks/#headers) for more information.
        :param pulumi.Input[_builtins.str] stack_name: Name of the stack. Only needed if this is a stack webhook.
        """
        pulumi.set(__self__, "active", active)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "organization_name", organization_name)
        pulumi.set(__self__, "payload_url", payload_url)
        if environment_name is not None:
            pulumi.set(__self__, "environment_name", environment_name)
        if filters is not None:
            pulumi.set(__self__, "filters", filters)
        if format is None:
            format = 'raw'
        if format is not None:
            pulumi.set(__self__, "format", format)
        if groups is not None:
            pulumi.set(__self__, "groups", groups)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)
        if stack_name is not None:
            pulumi.set(__self__, "stack_name", stack_name)

    @_builtins.property
    @pulumi.getter
    def active(self) -> pulumi.Input[_builtins.bool]:
        """
        Indicates whether this webhook is enabled or not.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "active", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        The friendly name displayed in the Pulumi Cloud.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the organization.
        """
        return pulumi.get(self, "organization_name")

    @organization_name.setter
    def organization_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "organization_name", value)

    @_builtins.property
    @pulumi.getter(name="payloadUrl")
    def payload_url(self) -> pulumi.Input[_builtins.str]:
        """
        URL to send request to.
        """
        return pulumi.get(self, "payload_url")

    @payload_url.setter
    def payload_url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "payload_url", value)

    @_builtins.property
    @pulumi.getter(name="environmentName")
    def environment_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the environment. Only specified if this is an environment webhook.
        """
        return pulumi.get(self, "environment_name")

    @environment_name.setter
    def environment_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "environment_name", value)

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WebhookFilters']]]]:
        """
        Optional set of filters to apply to the webhook. See [webhook docs](https://www.pulumi.com/docs/intro/pulumi-service/webhooks/#filters) for more information.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WebhookFilters']]]]):
        pulumi.set(self, "filters", value)

    @_builtins.property
    @pulumi.getter
    def format(self) -> Optional[pulumi.Input['WebhookFormat']]:
        """
        Format of the webhook payload. Can be either `raw` or `slack`. Defaults to `raw`.
        """
        return pulumi.get(self, "format")

    @format.setter
    def format(self, value: Optional[pulumi.Input['WebhookFormat']]):
        pulumi.set(self, "format", value)

    @_builtins.property
    @pulumi.getter
    def groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WebhookGroup']]]]:
        """
        Optional set of filter groups to apply to the webhook. See [webhook docs](https://www.pulumi.com/docs/intro/pulumi-service/webhooks/#groups) for more information.
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WebhookGroup']]]]):
        pulumi.set(self, "groups", value)

    @_builtins.property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the project. Only specified if this is a stack or environment webhook.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_name", value)

    @_builtins.property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Optional. secret used as the HMAC key. See [webhook docs](https://www.pulumi.com/docs/intro/pulumi-service/webhooks/#headers) for more information.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret", value)

    @_builtins.property
    @pulumi.getter(name="stackName")
    def stack_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the stack. Only needed if this is a stack webhook.
        """
        return pulumi.get(self, "stack_name")

    @stack_name.setter
    def stack_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "stack_name", value)


@pulumi.type_token("pulumiservice:index:Webhook")
class Webhook(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_name: Optional[pulumi.Input[_builtins.str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input['WebhookFilters']]]] = None,
                 format: Optional[pulumi.Input['WebhookFormat']] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input['WebhookGroup']]]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 payload_url: Optional[pulumi.Input[_builtins.str]] = None,
                 project_name: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 stack_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Pulumi Webhooks allow you to notify external services of events happening within your Pulumi organization or stack. For example, you can trigger a notification whenever a stack is updated. Whenever an event occurs, Pulumi will send an HTTP POST request to all registered webhooks. The webhook can then be used to emit some notification, start running integration tests, or even update additional stacks.

        ### Import

        Pulumi webhooks can be imported using the `id`, which for webhooks is `{org}/{project}/{stack}/{webhook-name}` e.g.,

        ```sh
         $ pulumi import pulumiservice:index:Webhook my_webhook my-org/my-project/my-stack/4b0d0671
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] active: Indicates whether this webhook is enabled or not.
        :param pulumi.Input[_builtins.str] display_name: The friendly name displayed in the Pulumi Cloud.
        :param pulumi.Input[_builtins.str] environment_name: Name of the environment. Only specified if this is an environment webhook.
        :param pulumi.Input[Sequence[pulumi.Input['WebhookFilters']]] filters: Optional set of filters to apply to the webhook. See [webhook docs](https://www.pulumi.com/docs/intro/pulumi-service/webhooks/#filters) for more information.
        :param pulumi.Input['WebhookFormat'] format: Format of the webhook payload. Can be either `raw` or `slack`. Defaults to `raw`.
        :param pulumi.Input[Sequence[pulumi.Input['WebhookGroup']]] groups: Optional set of filter groups to apply to the webhook. See [webhook docs](https://www.pulumi.com/docs/intro/pulumi-service/webhooks/#groups) for more information.
        :param pulumi.Input[_builtins.str] organization_name: Name of the organization.
        :param pulumi.Input[_builtins.str] payload_url: URL to send request to.
        :param pulumi.Input[_builtins.str] project_name: Name of the project. Only specified if this is a stack or environment webhook.
        :param pulumi.Input[_builtins.str] secret: Optional. secret used as the HMAC key. See [webhook docs](https://www.pulumi.com/docs/intro/pulumi-service/webhooks/#headers) for more information.
        :param pulumi.Input[_builtins.str] stack_name: Name of the stack. Only needed if this is a stack webhook.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WebhookArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Pulumi Webhooks allow you to notify external services of events happening within your Pulumi organization or stack. For example, you can trigger a notification whenever a stack is updated. Whenever an event occurs, Pulumi will send an HTTP POST request to all registered webhooks. The webhook can then be used to emit some notification, start running integration tests, or even update additional stacks.

        ### Import

        Pulumi webhooks can be imported using the `id`, which for webhooks is `{org}/{project}/{stack}/{webhook-name}` e.g.,

        ```sh
         $ pulumi import pulumiservice:index:Webhook my_webhook my-org/my-project/my-stack/4b0d0671
        ```

        :param str resource_name: The name of the resource.
        :param WebhookArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WebhookArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_name: Optional[pulumi.Input[_builtins.str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input['WebhookFilters']]]] = None,
                 format: Optional[pulumi.Input['WebhookFormat']] = None,
                 groups: Optional[pulumi.Input[Sequence[pulumi.Input['WebhookGroup']]]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 payload_url: Optional[pulumi.Input[_builtins.str]] = None,
                 project_name: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 stack_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WebhookArgs.__new__(WebhookArgs)

            if active is None and not opts.urn:
                raise TypeError("Missing required property 'active'")
            __props__.__dict__["active"] = active
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["environment_name"] = environment_name
            __props__.__dict__["filters"] = filters
            if format is None:
                format = 'raw'
            __props__.__dict__["format"] = format
            __props__.__dict__["groups"] = groups
            if organization_name is None and not opts.urn:
                raise TypeError("Missing required property 'organization_name'")
            __props__.__dict__["organization_name"] = organization_name
            if payload_url is None and not opts.urn:
                raise TypeError("Missing required property 'payload_url'")
            __props__.__dict__["payload_url"] = payload_url
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["secret"] = None if secret is None else pulumi.Output.secret(secret)
            __props__.__dict__["stack_name"] = stack_name
            __props__.__dict__["name"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Webhook, __self__).__init__(
            'pulumiservice:index:Webhook',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'Webhook':
        """
        Get an existing Webhook resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = WebhookArgs.__new__(WebhookArgs)

        __props__.__dict__["active"] = None
        __props__.__dict__["display_name"] = None
        __props__.__dict__["environment_name"] = None
        __props__.__dict__["filters"] = None
        __props__.__dict__["format"] = None
        __props__.__dict__["groups"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["organization_name"] = None
        __props__.__dict__["payload_url"] = None
        __props__.__dict__["project_name"] = None
        __props__.__dict__["secret"] = None
        __props__.__dict__["stack_name"] = None
        return Webhook(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def active(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether this webhook is enabled or not.
        """
        return pulumi.get(self, "active")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The friendly name displayed in the Pulumi Cloud.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="environmentName")
    def environment_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the environment. Only specified if this is an environment webhook.
        """
        return pulumi.get(self, "environment_name")

    @_builtins.property
    @pulumi.getter
    def filters(self) -> pulumi.Output[Optional[Sequence['WebhookFilters']]]:
        """
        Optional set of filters to apply to the webhook. See [webhook docs](https://www.pulumi.com/docs/intro/pulumi-service/webhooks/#filters) for more information.
        """
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def format(self) -> pulumi.Output['WebhookFormat']:
        """
        Format of the webhook payload. Can be either `raw`, `slack`, `ms_teams` or `pulumi_deployments`. Defaults to `raw`.
        """
        return pulumi.get(self, "format")

    @_builtins.property
    @pulumi.getter
    def groups(self) -> pulumi.Output[Optional[Sequence['WebhookGroup']]]:
        """
        Optional set of filter groups to apply to the webhook. See [webhook docs](https://www.pulumi.com/docs/intro/pulumi-service/webhooks/#groups) for more information.
        """
        return pulumi.get(self, "groups")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Webhook identifier generated by Pulumi Cloud.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the organization.
        """
        return pulumi.get(self, "organization_name")

    @_builtins.property
    @pulumi.getter(name="payloadUrl")
    def payload_url(self) -> pulumi.Output[_builtins.str]:
        """
        URL to send request to.
        """
        return pulumi.get(self, "payload_url")

    @_builtins.property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the project. Only specified if this is a stack or environment webhook.
        """
        return pulumi.get(self, "project_name")

    @_builtins.property
    @pulumi.getter
    def secret(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Optional. secret used as the HMAC key. See [webhook docs](https://www.pulumi.com/docs/intro/pulumi-service/webhooks/#headers) for more information.
        """
        return pulumi.get(self, "secret")

    @_builtins.property
    @pulumi.getter(name="stackName")
    def stack_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the stack. Only specified if this is a stack webhook.
        """
        return pulumi.get(self, "stack_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._enums import *
from ._inputs import *

__all__ = ['ApprovalRuleArgs', 'ApprovalRule']

@pulumi.input_type
class ApprovalRuleArgs:
    def __init__(__self__, *,
                 approval_rule_config: pulumi.Input['ApprovalRuleConfigArgs'],
                 enabled: pulumi.Input[_builtins.bool],
                 environment_identifier: pulumi.Input['EnvironmentIdentifierArgs'],
                 name: pulumi.Input[_builtins.str],
                 target_action_types: pulumi.Input[Sequence[pulumi.Input['TargetActionType']]]):
        """
        The set of arguments for constructing a ApprovalRule resource.
        :param pulumi.Input['ApprovalRuleConfigArgs'] approval_rule_config: The approval rule configuration.
        :param pulumi.Input[_builtins.bool] enabled: Whether the approval rule is enabled.
        :param pulumi.Input['EnvironmentIdentifierArgs'] environment_identifier: The environment this rule applies to.
        :param pulumi.Input[_builtins.str] name: The name of the approval rule.
        :param pulumi.Input[Sequence[pulumi.Input['TargetActionType']]] target_action_types: The type of action this rule applies to.
        """
        pulumi.set(__self__, "approval_rule_config", approval_rule_config)
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "environment_identifier", environment_identifier)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "target_action_types", target_action_types)

    @_builtins.property
    @pulumi.getter(name="approvalRuleConfig")
    def approval_rule_config(self) -> pulumi.Input['ApprovalRuleConfigArgs']:
        """
        The approval rule configuration.
        """
        return pulumi.get(self, "approval_rule_config")

    @approval_rule_config.setter
    def approval_rule_config(self, value: pulumi.Input['ApprovalRuleConfigArgs']):
        pulumi.set(self, "approval_rule_config", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[_builtins.bool]:
        """
        Whether the approval rule is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="environmentIdentifier")
    def environment_identifier(self) -> pulumi.Input['EnvironmentIdentifierArgs']:
        """
        The environment this rule applies to.
        """
        return pulumi.get(self, "environment_identifier")

    @environment_identifier.setter
    def environment_identifier(self, value: pulumi.Input['EnvironmentIdentifierArgs']):
        pulumi.set(self, "environment_identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the approval rule.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="targetActionTypes")
    def target_action_types(self) -> pulumi.Input[Sequence[pulumi.Input['TargetActionType']]]:
        """
        The type of action this rule applies to.
        """
        return pulumi.get(self, "target_action_types")

    @target_action_types.setter
    def target_action_types(self, value: pulumi.Input[Sequence[pulumi.Input['TargetActionType']]]):
        pulumi.set(self, "target_action_types", value)


@pulumi.type_token("pulumiservice:index:ApprovalRule")
class ApprovalRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 approval_rule_config: Optional[pulumi.Input[Union['ApprovalRuleConfigArgs', 'ApprovalRuleConfigArgsDict']]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 environment_identifier: Optional[pulumi.Input[Union['EnvironmentIdentifierArgs', 'EnvironmentIdentifierArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 target_action_types: Optional[pulumi.Input[Sequence[pulumi.Input['TargetActionType']]]] = None,
                 __props__=None):
        """
        An approval rule for environment deployments.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ApprovalRuleConfigArgs', 'ApprovalRuleConfigArgsDict']] approval_rule_config: The approval rule configuration.
        :param pulumi.Input[_builtins.bool] enabled: Whether the approval rule is enabled.
        :param pulumi.Input[Union['EnvironmentIdentifierArgs', 'EnvironmentIdentifierArgsDict']] environment_identifier: The environment this rule applies to.
        :param pulumi.Input[_builtins.str] name: The name of the approval rule.
        :param pulumi.Input[Sequence[pulumi.Input['TargetActionType']]] target_action_types: The type of action this rule applies to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApprovalRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        An approval rule for environment deployments.

        :param str resource_name: The name of the resource.
        :param ApprovalRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApprovalRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 approval_rule_config: Optional[pulumi.Input[Union['ApprovalRuleConfigArgs', 'ApprovalRuleConfigArgsDict']]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 environment_identifier: Optional[pulumi.Input[Union['EnvironmentIdentifierArgs', 'EnvironmentIdentifierArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 target_action_types: Optional[pulumi.Input[Sequence[pulumi.Input['TargetActionType']]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApprovalRuleArgs.__new__(ApprovalRuleArgs)

            if approval_rule_config is None and not opts.urn:
                raise TypeError("Missing required property 'approval_rule_config'")
            __props__.__dict__["approval_rule_config"] = approval_rule_config
            if enabled is None and not opts.urn:
                raise TypeError("Missing required property 'enabled'")
            __props__.__dict__["enabled"] = enabled
            if environment_identifier is None and not opts.urn:
                raise TypeError("Missing required property 'environment_identifier'")
            __props__.__dict__["environment_identifier"] = environment_identifier
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            if target_action_types is None and not opts.urn:
                raise TypeError("Missing required property 'target_action_types'")
            __props__.__dict__["target_action_types"] = target_action_types
        super(ApprovalRule, __self__).__init__(
            'pulumiservice:index:ApprovalRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'ApprovalRule':
        """
        Get an existing ApprovalRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = ApprovalRuleArgs.__new__(ApprovalRuleArgs)

        __props__.__dict__["approval_rule_config"] = None
        __props__.__dict__["enabled"] = None
        __props__.__dict__["environment_identifier"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["target_action_types"] = None
        return ApprovalRule(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="approvalRuleConfig")
    def approval_rule_config(self) -> pulumi.Output['outputs.ApprovalRuleConfig']:
        """
        The approval rule configuration.
        """
        return pulumi.get(self, "approval_rule_config")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the approval rule is enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="environmentIdentifier")
    def environment_identifier(self) -> pulumi.Output['outputs.EnvironmentIdentifier']:
        """
        The environment this rule applies to.
        """
        return pulumi.get(self, "environment_identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the approval rule.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="targetActionTypes")
    def target_action_types(self) -> pulumi.Output[Sequence['TargetActionType']]:
        """
        The type of action this rule applies to.
        """
        return pulumi.get(self, "target_action_types")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DeploymentSettingsArgs', 'DeploymentSettings']

@pulumi.input_type
class DeploymentSettingsArgs:
    def __init__(__self__, *,
                 organization: pulumi.Input[_builtins.str],
                 project: pulumi.Input[_builtins.str],
                 stack: pulumi.Input[_builtins.str],
                 agent_pool_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cache_options: Optional[pulumi.Input['DeploymentSettingsCacheOptionsArgs']] = None,
                 executor_context: Optional[pulumi.Input['DeploymentSettingsExecutorContextArgs']] = None,
                 github: Optional[pulumi.Input['DeploymentSettingsGithubArgs']] = None,
                 operation_context: Optional[pulumi.Input['DeploymentSettingsOperationContextArgs']] = None,
                 source_context: Optional[pulumi.Input['DeploymentSettingsSourceContextArgs']] = None,
                 vcs: Optional[pulumi.Input['DeploymentSettingsVcsArgs']] = None):
        """
        The set of arguments for constructing a DeploymentSettings resource.
        :param pulumi.Input[_builtins.str] organization: Organization name.
        :param pulumi.Input[_builtins.str] project: Project name.
        :param pulumi.Input[_builtins.str] stack: Stack name.
        :param pulumi.Input[_builtins.str] agent_pool_id: The agent pool identifier to use for the deployment.
        :param pulumi.Input['DeploymentSettingsCacheOptionsArgs'] cache_options: Dependency cache settings for the deployment
        :param pulumi.Input['DeploymentSettingsExecutorContextArgs'] executor_context: Settings related to the deployment executor.
        :param pulumi.Input['DeploymentSettingsGithubArgs'] github: GitHub settings for the deployment.
        :param pulumi.Input['DeploymentSettingsOperationContextArgs'] operation_context: Settings related to the Pulumi operation environment during the deployment.
        :param pulumi.Input['DeploymentSettingsSourceContextArgs'] source_context: Settings related to the source of the deployment.
        :param pulumi.Input['DeploymentSettingsVcsArgs'] vcs: VCS settings for the deployment. Supports Azure DevOps and GitHub via the 'provider' discriminator field.
        """
        pulumi.set(__self__, "organization", organization)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "stack", stack)
        if agent_pool_id is not None:
            pulumi.set(__self__, "agent_pool_id", agent_pool_id)
        if cache_options is not None:
            pulumi.set(__self__, "cache_options", cache_options)
        if executor_context is not None:
            pulumi.set(__self__, "executor_context", executor_context)
        if github is not None:
            warnings.warn("""Use the 'vcs' property instead, which supports both GitHub and Azure DevOps.""", DeprecationWarning)
            pulumi.log.warn("""github is deprecated: Use the 'vcs' property instead, which supports both GitHub and Azure DevOps.""")
        if github is not None:
            pulumi.set(__self__, "github", github)
        if operation_context is not None:
            pulumi.set(__self__, "operation_context", operation_context)
        if source_context is not None:
            pulumi.set(__self__, "source_context", source_context)
        if vcs is not None:
            pulumi.set(__self__, "vcs", vcs)

    @_builtins.property
    @pulumi.getter
    def organization(self) -> pulumi.Input[_builtins.str]:
        """
        Organization name.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "organization", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        Project name.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def stack(self) -> pulumi.Input[_builtins.str]:
        """
        Stack name.
        """
        return pulumi.get(self, "stack")

    @stack.setter
    def stack(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "stack", value)

    @_builtins.property
    @pulumi.getter(name="agentPoolId")
    def agent_pool_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The agent pool identifier to use for the deployment.
        """
        return pulumi.get(self, "agent_pool_id")

    @agent_pool_id.setter
    def agent_pool_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "agent_pool_id", value)

    @_builtins.property
    @pulumi.getter(name="cacheOptions")
    def cache_options(self) -> Optional[pulumi.Input['DeploymentSettingsCacheOptionsArgs']]:
        """
        Dependency cache settings for the deployment
        """
        return pulumi.get(self, "cache_options")

    @cache_options.setter
    def cache_options(self, value: Optional[pulumi.Input['DeploymentSettingsCacheOptionsArgs']]):
        pulumi.set(self, "cache_options", value)

    @_builtins.property
    @pulumi.getter(name="executorContext")
    def executor_context(self) -> Optional[pulumi.Input['DeploymentSettingsExecutorContextArgs']]:
        """
        Settings related to the deployment executor.
        """
        return pulumi.get(self, "executor_context")

    @executor_context.setter
    def executor_context(self, value: Optional[pulumi.Input['DeploymentSettingsExecutorContextArgs']]):
        pulumi.set(self, "executor_context", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Use the 'vcs' property instead, which supports both GitHub and Azure DevOps.""")
    def github(self) -> Optional[pulumi.Input['DeploymentSettingsGithubArgs']]:
        """
        GitHub settings for the deployment.
        """
        return pulumi.get(self, "github")

    @github.setter
    def github(self, value: Optional[pulumi.Input['DeploymentSettingsGithubArgs']]):
        pulumi.set(self, "github", value)

    @_builtins.property
    @pulumi.getter(name="operationContext")
    def operation_context(self) -> Optional[pulumi.Input['DeploymentSettingsOperationContextArgs']]:
        """
        Settings related to the Pulumi operation environment during the deployment.
        """
        return pulumi.get(self, "operation_context")

    @operation_context.setter
    def operation_context(self, value: Optional[pulumi.Input['DeploymentSettingsOperationContextArgs']]):
        pulumi.set(self, "operation_context", value)

    @_builtins.property
    @pulumi.getter(name="sourceContext")
    def source_context(self) -> Optional[pulumi.Input['DeploymentSettingsSourceContextArgs']]:
        """
        Settings related to the source of the deployment.
        """
        return pulumi.get(self, "source_context")

    @source_context.setter
    def source_context(self, value: Optional[pulumi.Input['DeploymentSettingsSourceContextArgs']]):
        pulumi.set(self, "source_context", value)

    @_builtins.property
    @pulumi.getter
    def vcs(self) -> Optional[pulumi.Input['DeploymentSettingsVcsArgs']]:
        """
        VCS settings for the deployment. Supports Azure DevOps and GitHub via the 'provider' discriminator field.
        """
        return pulumi.get(self, "vcs")

    @vcs.setter
    def vcs(self, value: Optional[pulumi.Input['DeploymentSettingsVcsArgs']]):
        pulumi.set(self, "vcs", value)


@pulumi.type_token("pulumiservice:index:DeploymentSettings")
class DeploymentSettings(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_pool_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cache_options: Optional[pulumi.Input[Union['DeploymentSettingsCacheOptionsArgs', 'DeploymentSettingsCacheOptionsArgsDict']]] = None,
                 executor_context: Optional[pulumi.Input[Union['DeploymentSettingsExecutorContextArgs', 'DeploymentSettingsExecutorContextArgsDict']]] = None,
                 github: Optional[pulumi.Input[Union['DeploymentSettingsGithubArgs', 'DeploymentSettingsGithubArgsDict']]] = None,
                 operation_context: Optional[pulumi.Input[Union['DeploymentSettingsOperationContextArgs', 'DeploymentSettingsOperationContextArgsDict']]] = None,
                 organization: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 source_context: Optional[pulumi.Input[Union['DeploymentSettingsSourceContextArgs', 'DeploymentSettingsSourceContextArgsDict']]] = None,
                 stack: Optional[pulumi.Input[_builtins.str]] = None,
                 vcs: Optional[pulumi.Input[Union['DeploymentSettingsVcsArgs', 'DeploymentSettingsVcsArgsDict']]] = None,
                 __props__=None):
        """
        Deployment settings configure Pulumi Deployments for a stack.

        ### Import

        Deployment settings can be imported using the `id`, which for deployment settings is `{org}/{project}/{stack}` e.g.,

        ```sh
         $ pulumi import pulumiservice:index:DeploymentSettings my_settings my-org/my-project/my-stack
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] agent_pool_id: The agent pool identifier to use for the deployment.
        :param pulumi.Input[Union['DeploymentSettingsCacheOptionsArgs', 'DeploymentSettingsCacheOptionsArgsDict']] cache_options: Dependency cache settings for the deployment
        :param pulumi.Input[Union['DeploymentSettingsExecutorContextArgs', 'DeploymentSettingsExecutorContextArgsDict']] executor_context: Settings related to the deployment executor.
        :param pulumi.Input[Union['DeploymentSettingsGithubArgs', 'DeploymentSettingsGithubArgsDict']] github: GitHub settings for the deployment.
        :param pulumi.Input[Union['DeploymentSettingsOperationContextArgs', 'DeploymentSettingsOperationContextArgsDict']] operation_context: Settings related to the Pulumi operation environment during the deployment.
        :param pulumi.Input[_builtins.str] organization: Organization name.
        :param pulumi.Input[_builtins.str] project: Project name.
        :param pulumi.Input[Union['DeploymentSettingsSourceContextArgs', 'DeploymentSettingsSourceContextArgsDict']] source_context: Settings related to the source of the deployment.
        :param pulumi.Input[_builtins.str] stack: Stack name.
        :param pulumi.Input[Union['DeploymentSettingsVcsArgs', 'DeploymentSettingsVcsArgsDict']] vcs: VCS settings for the deployment. Supports Azure DevOps and GitHub via the 'provider' discriminator field.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DeploymentSettingsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Deployment settings configure Pulumi Deployments for a stack.

        ### Import

        Deployment settings can be imported using the `id`, which for deployment settings is `{org}/{project}/{stack}` e.g.,

        ```sh
         $ pulumi import pulumiservice:index:DeploymentSettings my_settings my-org/my-project/my-stack
        ```

        :param str resource_name: The name of the resource.
        :param DeploymentSettingsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeploymentSettingsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_pool_id: Optional[pulumi.Input[_builtins.str]] = None,
                 cache_options: Optional[pulumi.Input[Union['DeploymentSettingsCacheOptionsArgs', 'DeploymentSettingsCacheOptionsArgsDict']]] = None,
                 executor_context: Optional[pulumi.Input[Union['DeploymentSettingsExecutorContextArgs', 'DeploymentSettingsExecutorContextArgsDict']]] = None,
                 github: Optional[pulumi.Input[Union['DeploymentSettingsGithubArgs', 'DeploymentSettingsGithubArgsDict']]] = None,
                 operation_context: Optional[pulumi.Input[Union['DeploymentSettingsOperationContextArgs', 'DeploymentSettingsOperationContextArgsDict']]] = None,
                 organization: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 source_context: Optional[pulumi.Input[Union['DeploymentSettingsSourceContextArgs', 'DeploymentSettingsSourceContextArgsDict']]] = None,
                 stack: Optional[pulumi.Input[_builtins.str]] = None,
                 vcs: Optional[pulumi.Input[Union['DeploymentSettingsVcsArgs', 'DeploymentSettingsVcsArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeploymentSettingsArgs.__new__(DeploymentSettingsArgs)

            __props__.__dict__["agent_pool_id"] = agent_pool_id
            __props__.__dict__["cache_options"] = cache_options
            __props__.__dict__["executor_context"] = executor_context
            __props__.__dict__["github"] = github
            __props__.__dict__["operation_context"] = operation_context
            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["source_context"] = source_context
            if stack is None and not opts.urn:
                raise TypeError("Missing required property 'stack'")
            __props__.__dict__["stack"] = stack
            __props__.__dict__["vcs"] = vcs
        super(DeploymentSettings, __self__).__init__(
            'pulumiservice:index:DeploymentSettings',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'DeploymentSettings':
        """
        Get an existing DeploymentSettings resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = DeploymentSettingsArgs.__new__(DeploymentSettingsArgs)

        __props__.__dict__["agent_pool_id"] = None
        __props__.__dict__["cache_options"] = None
        __props__.__dict__["executor_context"] = None
        __props__.__dict__["github"] = None
        __props__.__dict__["operation_context"] = None
        __props__.__dict__["organization"] = None
        __props__.__dict__["project"] = None
        __props__.__dict__["source_context"] = None
        __props__.__dict__["stack"] = None
        __props__.__dict__["vcs"] = None
        return DeploymentSettings(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="agentPoolId")
    def agent_pool_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The agent pool identifier to use for the deployment.
        """
        return pulumi.get(self, "agent_pool_id")

    @_builtins.property
    @pulumi.getter(name="cacheOptions")
    def cache_options(self) -> pulumi.Output[Optional['outputs.DeploymentSettingsCacheOptions']]:
        """
        Dependency cache settings for the deployment
        """
        return pulumi.get(self, "cache_options")

    @_builtins.property
    @pulumi.getter(name="executorContext")
    def executor_context(self) -> pulumi.Output[Optional['outputs.DeploymentSettingsExecutorContext']]:
        """
        Settings related to the deployment executor.
        """
        return pulumi.get(self, "executor_context")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Use the 'vcs' property instead, which supports both GitHub and Azure DevOps.""")
    def github(self) -> pulumi.Output[Optional['outputs.DeploymentSettingsGithub']]:
        """
        GitHub settings for the deployment.
        """
        return pulumi.get(self, "github")

    @_builtins.property
    @pulumi.getter(name="operationContext")
    def operation_context(self) -> pulumi.Output[Optional['outputs.DeploymentSettingsOperationContext']]:
        """
        Settings related to the Pulumi operation environment during the deployment.
        """
        return pulumi.get(self, "operation_context")

    @_builtins.property
    @pulumi.getter
    def organization(self) -> pulumi.Output[_builtins.str]:
        """
        Organization name.
        """
        return pulumi.get(self, "organization")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        Project name.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="sourceContext")
    def source_context(self) -> pulumi.Output[Optional['outputs.DeploymentSettingsSourceContext']]:
        """
        Settings related to the source of the deployment.
        """
        return pulumi.get(self, "source_context")

    @_builtins.property
    @pulumi.getter
    def stack(self) -> pulumi.Output[_builtins.str]:
        """
        Stack name.
        """
        return pulumi.get(self, "stack")

    @_builtins.property
    @pulumi.getter
    def vcs(self) -> pulumi.Output[Optional['outputs.DeploymentSettingsVcs']]:
        """
        VCS settings for the deployment. Supports Azure DevOps and GitHub via the 'provider' discriminator field.
        """
        return pulumi.get(self, "vcs")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TemplateSourceArgs', 'TemplateSource']

@pulumi.input_type
class TemplateSourceArgs:
    def __init__(__self__, *,
                 organization_name: pulumi.Input[_builtins.str],
                 source_name: pulumi.Input[_builtins.str],
                 source_url: pulumi.Input[_builtins.str],
                 destination: Optional[pulumi.Input['TemplateSourceDestinationArgs']] = None):
        """
        The set of arguments for constructing a TemplateSource resource.
        :param pulumi.Input[_builtins.str] organization_name: Organization name.
        :param pulumi.Input[_builtins.str] source_name: Source name.
        :param pulumi.Input[_builtins.str] source_url: Github URL of the repository from which to grab templates.
        :param pulumi.Input['TemplateSourceDestinationArgs'] destination: The default destination for projects using templates from this source.
        """
        pulumi.set(__self__, "organization_name", organization_name)
        pulumi.set(__self__, "source_name", source_name)
        pulumi.set(__self__, "source_url", source_url)
        if destination is not None:
            pulumi.set(__self__, "destination", destination)

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> pulumi.Input[_builtins.str]:
        """
        Organization name.
        """
        return pulumi.get(self, "organization_name")

    @organization_name.setter
    def organization_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "organization_name", value)

    @_builtins.property
    @pulumi.getter(name="sourceName")
    def source_name(self) -> pulumi.Input[_builtins.str]:
        """
        Source name.
        """
        return pulumi.get(self, "source_name")

    @source_name.setter
    def source_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "source_name", value)

    @_builtins.property
    @pulumi.getter(name="sourceURL")
    def source_url(self) -> pulumi.Input[_builtins.str]:
        """
        Github URL of the repository from which to grab templates.
        """
        return pulumi.get(self, "source_url")

    @source_url.setter
    def source_url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "source_url", value)

    @_builtins.property
    @pulumi.getter
    def destination(self) -> Optional[pulumi.Input['TemplateSourceDestinationArgs']]:
        """
        The default destination for projects using templates from this source.
        """
        return pulumi.get(self, "destination")

    @destination.setter
    def destination(self, value: Optional[pulumi.Input['TemplateSourceDestinationArgs']]):
        pulumi.set(self, "destination", value)


@pulumi.type_token("pulumiservice:index:TemplateSource")
class TemplateSource(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 destination: Optional[pulumi.Input[Union['TemplateSourceDestinationArgs', 'TemplateSourceDestinationArgsDict']]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 source_name: Optional[pulumi.Input[_builtins.str]] = None,
                 source_url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        A source for Pulumi templates

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['TemplateSourceDestinationArgs', 'TemplateSourceDestinationArgsDict']] destination: The default destination for projects using templates from this source.
        :param pulumi.Input[_builtins.str] organization_name: Organization name.
        :param pulumi.Input[_builtins.str] source_name: Source name.
        :param pulumi.Input[_builtins.str] source_url: Github URL of the repository from which to grab templates.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TemplateSourceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A source for Pulumi templates

        :param str resource_name: The name of the resource.
        :param TemplateSourceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TemplateSourceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 destination: Optional[pulumi.Input[Union['TemplateSourceDestinationArgs', 'TemplateSourceDestinationArgsDict']]] = None,
                 organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                 source_name: Optional[pulumi.Input[_builtins.str]] = None,
                 source_url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TemplateSourceArgs.__new__(TemplateSourceArgs)

            __props__.__dict__["destination"] = destination
            if organization_name is None and not opts.urn:
                raise TypeError("Missing required property 'organization_name'")
            __props__.__dict__["organization_name"] = organization_name
            if source_name is None and not opts.urn:
                raise TypeError("Missing required property 'source_name'")
            __props__.__dict__["source_name"] = source_name
            if source_url is None and not opts.urn:
                raise TypeError("Missing required property 'source_url'")
            __props__.__dict__["source_url"] = source_url
        super(TemplateSource, __self__).__init__(
            'pulumiservice:index:TemplateSource',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'TemplateSource':
        """
        Get an existing TemplateSource resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = TemplateSourceArgs.__new__(TemplateSourceArgs)

        __props__.__dict__["destination"] = None
        __props__.__dict__["organization_name"] = None
        __props__.__dict__["source_name"] = None
        __props__.__dict__["source_url"] = None
        return TemplateSource(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def destination(self) -> pulumi.Output[Optional['outputs.TemplateSourceDestination']]:
        """
        The default destination for projects using templates from this source.
        """
        return pulumi.get(self, "destination")

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> pulumi.Output[_builtins.str]:
        """
        Organization name.
        """
        return pulumi.get(self, "organization_name")

    @_builtins.property
    @pulumi.getter(name="sourceName")
    def source_name(self) -> pulumi.Output[_builtins.str]:
        """
        Source name.
        """
        return pulumi.get(self, "source_name")

    @_builtins.property
    @pulumi.getter(name="sourceURL")
    def source_url(self) -> pulumi.Output[_builtins.str]:
        """
        Github URL of the repository from which to grab templates.
        """
        return pulumi.get(self, "source_url")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from ._enums import *

__all__ = [
    'GetInsightsAccountResult',
    'AwaitableGetInsightsAccountResult',
    'get_insights_account',
    'get_insights_account_output',
]

@pulumi.output_type
class GetInsightsAccountResult:
    def __init__(__self__, account_name=None, environment=None, insights_account_id=None, organization_name=None, provider=None, provider_config=None, scan_schedule=None, scheduled_scan_enabled=None, tags=None):
        if account_name and not isinstance(account_name, str):
            raise TypeError("Expected argument 'account_name' to be a str")
        pulumi.set(__self__, "account_name", account_name)
        if environment and not isinstance(environment, str):
            raise TypeError("Expected argument 'environment' to be a str")
        pulumi.set(__self__, "environment", environment)
        if insights_account_id and not isinstance(insights_account_id, str):
            raise TypeError("Expected argument 'insights_account_id' to be a str")
        pulumi.set(__self__, "insights_account_id", insights_account_id)
        if organization_name and not isinstance(organization_name, str):
            raise TypeError("Expected argument 'organization_name' to be a str")
        pulumi.set(__self__, "organization_name", organization_name)
        if provider and not isinstance(provider, str):
            raise TypeError("Expected argument 'provider' to be a str")
        pulumi.set(__self__, "provider", provider)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if scan_schedule and not isinstance(scan_schedule, str):
            raise TypeError("Expected argument 'scan_schedule' to be a str")
        pulumi.set(__self__, "scan_schedule", scan_schedule)
        if scheduled_scan_enabled and not isinstance(scheduled_scan_enabled, bool):
            raise TypeError("Expected argument 'scheduled_scan_enabled' to be a bool")
        pulumi.set(__self__, "scheduled_scan_enabled", scheduled_scan_enabled)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="accountName")
    def account_name(self) -> _builtins.str:
        """
        Name of the insights account.
        """
        return pulumi.get(self, "account_name")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> _builtins.str:
        """
        The ESC environment used for provider credentials. Format: 'project/environment' with optional '@version' suffix (e.g., 'my-project/prod-env' or 'my-project/prod-env@v1.0').
        """
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter(name="insightsAccountId")
    def insights_account_id(self) -> _builtins.str:
        """
        The insights account identifier.
        """
        return pulumi.get(self, "insights_account_id")

    @_builtins.property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> _builtins.str:
        """
        The organization's name.
        """
        return pulumi.get(self, "organization_name")

    @_builtins.property
    @pulumi.getter
    def provider(self) -> 'CloudProvider':
        """
        The cloud provider for scanning.
        """
        return pulumi.get(self, "provider")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[Mapping[str, Any]]:
        """
        Provider-specific configuration as a JSON object. For AWS, specify regions to scan: {"regions": ["us-west-1", "us-west-2"]}.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="scanSchedule")
    def scan_schedule(self) -> 'ScanSchedule':
        """
        Schedule for automated scanning. Use 'daily' to enable daily scans, or 'none' to disable scheduled scanning. Defaults to 'none'.
        """
        return pulumi.get(self, "scan_schedule")

    @_builtins.property
    @pulumi.getter(name="scheduledScanEnabled")
    def scheduled_scan_enabled(self) -> _builtins.bool:
        """
        Whether scheduled scanning is enabled.
        """
        return pulumi.get(self, "scheduled_scan_enabled")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, _builtins.str]]:
        """
        Key-value tags to associate with the insights account.
        """
        return pulumi.get(self, "tags")


class AwaitableGetInsightsAccountResult(GetInsightsAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInsightsAccountResult(
            account_name=self.account_name,
            environment=self.environment,
            insights_account_id=self.insights_account_id,
            organization_name=self.organization_name,
            provider=self.provider,
            provider_config=self.provider_config,
            scan_schedule=self.scan_schedule,
            scheduled_scan_enabled=self.scheduled_scan_enabled,
            tags=self.tags)


def get_insights_account(account_name: Optional[_builtins.str] = None,
                         organization_name: Optional[_builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInsightsAccountResult:
    """
    Get details about a specific Insights account.
    """
    __args__ = dict()
    __args__['accountName'] = account_name
    __args__['organizationName'] = organization_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('pulumiservice:index:getInsightsAccount', __args__, opts=opts, typ=GetInsightsAccountResult).value

    return AwaitableGetInsightsAccountResult(
        account_name=pulumi.get(__ret__, 'account_name'),
        environment=pulumi.get(__ret__, 'environment'),
        insights_account_id=pulumi.get(__ret__, 'insights_account_id'),
        organization_name=pulumi.get(__ret__, 'organization_name'),
        provider=pulumi.get(__ret__, 'provider'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        scan_schedule=pulumi.get(__ret__, 'scan_schedule'),
        scheduled_scan_enabled=pulumi.get(__ret__, 'scheduled_scan_enabled'),
        tags=pulumi.get(__ret__, 'tags'))
def get_insights_account_output(account_name: Optional[pulumi.Input[_builtins.str]] = None,
                                organization_name: Optional[pulumi.Input[_builtins.str]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInsightsAccountResult]:
    """
    Get details about a specific Insights account.
    """
    __args__ = dict()
    __args__['accountName'] = account_name
    __args__['organizationName'] = organization_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('pulumiservice:index:getInsightsAccount', __args__, opts=opts, typ=GetInsightsAccountResult)
    return __ret__.apply(lambda __response__: GetInsightsAccountResult(
        account_name=pulumi.get(__response__, 'account_name'),
        environment=pulumi.get(__response__, 'environment'),
        insights_account_id=pulumi.get(__response__, 'insights_account_id'),
        organization_name=pulumi.get(__response__, 'organization_name'),
        provider=pulumi.get(__response__, 'provider'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        scan_schedule=pulumi.get(__response__, 'scan_schedule'),
        scheduled_scan_enabled=pulumi.get(__response__, 'scheduled_scan_enabled'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._enums import *
from ._inputs import *

__all__ = ['OidcIssuerArgs', 'OidcIssuer']

@pulumi.input_type
class OidcIssuerArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[_builtins.str],
                 organization: pulumi.Input[_builtins.str],
                 url: pulumi.Input[_builtins.str],
                 max_expiration_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input['AuthPolicyDefinitionArgs']]]] = None,
                 thumbprints: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a OidcIssuer resource.
        :param pulumi.Input[_builtins.str] name: Issuer name.
        :param pulumi.Input[_builtins.str] organization: Organization name.
        :param pulumi.Input[_builtins.str] url: The OIDC issuer URL.
        :param pulumi.Input[_builtins.int] max_expiration_seconds: The maximum duration of the Pulumi access token working after an exchange, specified in seconds.
        :param pulumi.Input[Sequence[pulumi.Input['AuthPolicyDefinitionArgs']]] policies: The auth policies for this Oidc Issuer.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] thumbprints: The thumbprints of issuer's TLS certificates. By default, Pulumi will store the thumbprint of the certificate used to serve the OpenID configuration. If the provider uses multiple certificates to serve content, it is required to manually configure these.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "organization", organization)
        pulumi.set(__self__, "url", url)
        if max_expiration_seconds is not None:
            pulumi.set(__self__, "max_expiration_seconds", max_expiration_seconds)
        if policies is not None:
            pulumi.set(__self__, "policies", policies)
        if thumbprints is not None:
            pulumi.set(__self__, "thumbprints", thumbprints)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        Issuer name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def organization(self) -> pulumi.Input[_builtins.str]:
        """
        Organization name.
        """
        return pulumi.get(self, "organization")

    @organization.setter
    def organization(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "organization", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Input[_builtins.str]:
        """
        The OIDC issuer URL.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter(name="maxExpirationSeconds")
    def max_expiration_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum duration of the Pulumi access token working after an exchange, specified in seconds.
        """
        return pulumi.get(self, "max_expiration_seconds")

    @max_expiration_seconds.setter
    def max_expiration_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_expiration_seconds", value)

    @_builtins.property
    @pulumi.getter
    def policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AuthPolicyDefinitionArgs']]]]:
        """
        The auth policies for this Oidc Issuer.
        """
        return pulumi.get(self, "policies")

    @policies.setter
    def policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AuthPolicyDefinitionArgs']]]]):
        pulumi.set(self, "policies", value)

    @_builtins.property
    @pulumi.getter
    def thumbprints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The thumbprints of issuer's TLS certificates. By default, Pulumi will store the thumbprint of the certificate used to serve the OpenID configuration. If the provider uses multiple certificates to serve content, it is required to manually configure these.
        """
        return pulumi.get(self, "thumbprints")

    @thumbprints.setter
    def thumbprints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "thumbprints", value)


@pulumi.type_token("pulumiservice:index:OidcIssuer")
class OidcIssuer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 max_expiration_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization: Optional[pulumi.Input[_builtins.str]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthPolicyDefinitionArgs', 'AuthPolicyDefinitionArgsDict']]]]] = None,
                 thumbprints: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Register an OIDC Provider to establish a trust relationship between third-party systems like GitHub Actions and Pulumi Cloud, obviating the need to store a hard-coded Pulumi Cloud token in systems that need to run Pulumi commands or consume Pulumi Cloud APIs. Instead of a hard-coded, static token that must be manually rotated, trusted systems are granted temporary Pulumi Cloud tokens on an as-needed basis, which is more secure than static tokens.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] max_expiration_seconds: The maximum duration of the Pulumi access token working after an exchange, specified in seconds.
        :param pulumi.Input[_builtins.str] name: Issuer name.
        :param pulumi.Input[_builtins.str] organization: Organization name.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AuthPolicyDefinitionArgs', 'AuthPolicyDefinitionArgsDict']]]] policies: The auth policies for this Oidc Issuer.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] thumbprints: The thumbprints of issuer's TLS certificates. By default, Pulumi will store the thumbprint of the certificate used to serve the OpenID configuration. If the provider uses multiple certificates to serve content, it is required to manually configure these.
        :param pulumi.Input[_builtins.str] url: The OIDC issuer URL.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OidcIssuerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Register an OIDC Provider to establish a trust relationship between third-party systems like GitHub Actions and Pulumi Cloud, obviating the need to store a hard-coded Pulumi Cloud token in systems that need to run Pulumi commands or consume Pulumi Cloud APIs. Instead of a hard-coded, static token that must be manually rotated, trusted systems are granted temporary Pulumi Cloud tokens on an as-needed basis, which is more secure than static tokens.

        :param str resource_name: The name of the resource.
        :param OidcIssuerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OidcIssuerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 max_expiration_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization: Optional[pulumi.Input[_builtins.str]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthPolicyDefinitionArgs', 'AuthPolicyDefinitionArgsDict']]]]] = None,
                 thumbprints: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OidcIssuerArgs.__new__(OidcIssuerArgs)

            __props__.__dict__["max_expiration_seconds"] = max_expiration_seconds
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            if organization is None and not opts.urn:
                raise TypeError("Missing required property 'organization'")
            __props__.__dict__["organization"] = organization
            __props__.__dict__["policies"] = policies
            __props__.__dict__["thumbprints"] = thumbprints
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
        replace_on_changes = pulumi.ResourceOptions(replace_on_changes=["organization", "url"])
        opts = pulumi.ResourceOptions.merge(opts, replace_on_changes)
        super(OidcIssuer, __self__).__init__(
            'pulumiservice:index:OidcIssuer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'OidcIssuer':
        """
        Get an existing OidcIssuer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = OidcIssuerArgs.__new__(OidcIssuerArgs)

        __props__.__dict__["max_expiration_seconds"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["organization"] = None
        __props__.__dict__["policies"] = None
        __props__.__dict__["thumbprints"] = None
        __props__.__dict__["url"] = None
        return OidcIssuer(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="maxExpirationSeconds")
    def max_expiration_seconds(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The maximum duration of the Pulumi access token working after an exchange, specified in seconds.
        """
        return pulumi.get(self, "max_expiration_seconds")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Issuer name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def organization(self) -> pulumi.Output[_builtins.str]:
        """
        Organization name.
        """
        return pulumi.get(self, "organization")

    @_builtins.property
    @pulumi.getter
    def policies(self) -> pulumi.Output[Sequence['outputs.AuthPolicyDefinition']]:
        """
        The authorization policies for this Oidc Issuer.
        """
        return pulumi.get(self, "policies")

    @_builtins.property
    @pulumi.getter
    def thumbprints(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The thumbprints of issuer's TLS certificates. By default, Pulumi will store the thumbprint of the certificate used to serve the OpenID configuration. If the provider uses multiple certificates to serve content, it is required to manually configure these.
        """
        return pulumi.get(self, "thumbprints")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        The OIDC issuer URL.
        """
        return pulumi.get(self, "url")

